package com.cpxt.biz.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cpxt.biz.domain.BizCarState;
import java.util.List;

/**
 * 车辆实时状态Service接口
 * 
 * @author ruoyi
 * @date 2024-12-18
 */
public interface IBizCarStateService 
{
    /**
     * 查询车辆实时状态
     * 
     * @param id 车辆实时状态主键
     * @return 车辆实时状态
     */
    public BizCarState selectBizCarStateById(Long id);

    /**
     * 查询车辆实时状态列表
     * 
     * @param bizCarState 车辆实时状态
     * @return 车辆实时状态集合
     */
    public List<BizCarState> selectBizCarStateList(BizCarState bizCarState);

    /**
     * 新增车辆实时状态
     * 
     * @param bizCarState 车辆实时状态
     * @return 结果
     */
    public int insertBizCarState(BizCarState bizCarState);

    /**
     * 修改车辆实时状态
     * 
     * @param bizCarState 车辆实时状态
     * @return 结果
     */
    public int updateBizCarState(BizCarState bizCarState);

    /**
     * 批量删除车辆实时状态
     * 
     * @param ids 需要删除的车辆实时状态主键集合
     * @return 结果
     */
    public int deleteBizCarStateByIds(Long[] ids);

    /**
     * 删除车辆实时状态信息
     * 
     * @param id 车辆实时状态主键
     * @return 结果
     */
    public int deleteBizCarStateById(Long id);

    Page<BizCarState> selectBizCarStatePage(BizCarState bizCarState, int pageNum, int pageSize);

    BizCarState selectBizCarStateByCarId(Long carId);
}
